==> trilinos_9.0.3.dfsg.orig.tar.gz: trilinos-9.0.3.dfsg.orig/packages/Sundance/src-solvers/Concrete/TSFEpetraGhostView.cpp <==
/* ***********************************************************************
// 
//           TSFExtended: Trilinos Solver Framework Extended
//                 Copyright (2004) Sandia Corporation
// 
// Under terms of Contract DE-AC04-94AL85000, there is a non-exclusive
// license for use of this work by or on behalf of the U.S. Government.
// 
// This library is free software; you can redistribute it and/or modify
// it under the terms of the GNU Lesser General Public License as
// published by the Free Software Foundation; either version 2.1 of the
// License, or (at your option) any later version.
//  
// This library is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// Lesser General Public License for more details.
//  
// You should have received a copy of the GNU Lesser General Public
// License along with this library; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
// USA
// Questions? Contact Michael A. Heroux (maherou@sandia.gov) 
// 
// **********************************************************************/

#include "TSFEpetraGhostView.hpp"
#include "Epetra_Import.h"

using namespace Teuchos;
using namespace TSFExtended;

const double& EpetraGhostView::getElement(int globalIndex) const 
{
  const Epetra_BlockMap& myMap = ghostView_->Map();
  return (*ghostView_)[myMap.LID(globalIndex)];
}

void EpetraGhostView::getElements(const int* globalIndices, int numElems,
                                  std::vector<double>& elems) const
{
  elems.resize(numElems);
  const Epetra_BlockMap& myMap = ghostView_->Map();

  for (int i=0; i<numElems; i++)
    {
      elems[i] = (*ghostView_)[myMap.LID(globalIndices[i])];
    }
}

void  EpetraGhostView::import(const Epetra_Import& importer,
                              const Epetra_Vector& srcObject)
{
  /* If my vector does not yet exist, create it using the target map of the
   * importer */
  if (ghostView_.get()==0)
    {
      ghostView_ = rcp(new Epetra_Vector(importer.TargetMap()));
    }

  /* do the import */
  int ierr = ghostView_->Import(srcObject, importer, Insert);
  TEST_FOR_EXCEPTION(ierr < 0, std::runtime_error, "ierr=" << ierr << " in EpetraGhostView::import()");
}

void EpetraGhostView::print(ostream& os) const
{
  if (ghostView_.get()==0) 
    {
      os << "[null Epetra ghost view]" << endl;
    }
  else
    {
      ghostView_->Print(os);
    }
}

==> trilinos_10.0.4.dfsg.orig.tar.gz: trilinos-10.0.4.dfsg.orig/packages/Sundance/src-solvers/Concrete/TSFEpetraGhostView.cpp <==
/* ***********************************************************************
// 
//           TSFExtended: Trilinos Solver Framework Extended
//                 Copyright (2004) Sandia Corporation
// 
// Under terms of Contract DE-AC04-94AL85000, there is a non-exclusive
// license for use of this work by or on behalf of the U.S. Government.
// 
// This library is free software; you can redistribute it and/or modify
// it under the terms of the GNU Lesser General Public License as
// published by the Free Software Foundation; either version 2.1 of the
// License, or (at your option) any later version.
//  
// This library is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// Lesser General Public License for more details.
//  
// You should have received a copy of the GNU Lesser General Public
// License along with this library; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
// USA
// Questions? Contact Michael A. Heroux (maherou@sandia.gov) 
// 
// **********************************************************************/

#include "TSFEpetraGhostView.hpp"
#include "Epetra_Import.h"


using namespace Teuchos;
using namespace TSFExtended;

const double& EpetraGhostView::getElement(int globalIndex) const 
{
  const Epetra_BlockMap& myMap = ghostView_->Map();
  return (*ghostView_)[myMap.LID(globalIndex)];
}

void EpetraGhostView::getElements(const int* globalIndices, int numElems,
                                  Array<double>& elems) const
{
  elems.resize(numElems);
  const Epetra_BlockMap& myMap = ghostView_->Map();

  for (int i=0; i<numElems; i++)
    {
      elems[i] = (*ghostView_)[myMap.LID(globalIndices[i])];
    }
}

void  EpetraGhostView::import(const Epetra_Import& importer,
                              const Epetra_Vector& srcObject)
{
  /* If my vector does not yet exist, create it using the target map of the
   * importer */
  if (ghostView_.get()==0)
    {
      ghostView_ = rcp(new Epetra_Vector(importer.TargetMap()));
    }

  /* do the import */
  int ierr = ghostView_->Import(srcObject, importer, Insert);
  TEST_FOR_EXCEPTION(ierr < 0, std::runtime_error, "ierr=" << ierr << " in EpetraGhostView::import()");
}

void EpetraGhostView::print(ostream& os) const
{
  if (ghostView_.get()==0) 
    {
      os << "[null Epetra ghost view]" << endl;
    }
  else
    {
      ghostView_->Print(os);
    }
}
